@@ -43,12 +43,13 @@ class CDSLShell(BasicShell):
         super(self.__class__, self).__init__()
         self.debug = False
         self.schemes = [
-            sanscript.HK,
-            sanscript.VELTHUIS,
+            sanscript.DEVANAGARI,
+            sanscript.IAST,
             sanscript.ITRANS,
+            sanscript.VELTHUIS,
+            sanscript.HK,
             sanscript.SLP1,
             sanscript.WX,
-            sanscript.DEVANAGARI
         ]
         self.input_scheme = sanscript.DEVANAGARI
 
@@ -96,6 +97,7 @@ class CDSLShell(BasicShell):
     # Dictionary Information
 
     def do_info(self, text=None):
+        """Display information about the active dictionary"""
         if self.active is None:
             self.logger.error("Please select a dictionary first.")
         else:
@@ -150,7 +152,7 @@ class CDSLShell(BasicShell):
     # ----------------------------------------------------------------------- #
 
     def do_version(self, text):
-        """Version of the PyCDSL"""
+        """Show the current version of PyCDSL"""
         print(__version__)
 
     # ----------------------------------------------------------------------- #
